# json-tore-python-sdk
This is a python sdk client for json-tore

## install
'''python setup.py install'''

## instruction
user needs to setup json-tore host and port by setting environment variable '''JT_HOST''' and '''JT_PORT'''

do
'''
from jtSDK.jtClient import jtClient
client = jtClient()
'''
